==> u61-0.3.3.tar.gz: u61-0.3.3/src/joinmenu.cpp <==
/****************************************************************************
 *                                                                          *
 * U U    6   1            U U   FFF  O   O  TTT                            *
 * U U   6   11   b        U U   F   O O O O  T                             *
 * U U - 66   1   bb  y y  U U - FF  O O O O  T                             *
 * U U   6 6  1   b b  y   U U   F   O O O O  T                             *
 *  U     6   1   bb   y    U    F    O   O   T                             *
 *                                                                          *
 * U61 is another block based game                                          *
 * Copyright (C) 2000 Christian Mauduit (ufoot@ufoot.org / www.ufoot.org)   *
 *                                                                          *
 * This program is free software; you can redistribute it and/or            *
 * modify it under the terms of the GNU General Public License              *
 * as published by the Free Software Foundation; either version 2           *
 * of the License, or (at your option) any later version.                   *
 *                                                                          *
 * This program is distributed in the hope that it will be useful,          *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of           *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
 * GNU General Public License for more details.                             *
 *                                                                          *
 * You should have received a copy of the GNU General Public License        *
 * along with this program; if not, write to the Free Software              *
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA*
 *                                                                          *
 * This project is also available on SourceForge  (http://sourceforge.net)  *
 ****************************************************************************/

/*
 * file name:   joinmenu.cpp
 * author:      U-Foot (ufoot@ufoot.org / www.ufoot.org)
 * description: allows the user to choose a remote machine and start
 *              a netwotk game being a client
 */

/*---------------------------------------------------------------------------
 includes
 ---------------------------------------------------------------------------*/

#include "joinmenu.h"
#include "networkmenu.h"
#include "nonpausingmenu.h"
#include "button.h"
#include "edit.h"
#include "global.h"
#include "savescriptmenu.h"
#include "scoremenu.h"

/*---------------------------------------------------------------------------
 globals
 ---------------------------------------------------------------------------*/


/*---------------------------------------------------------------------------
 functions
 ---------------------------------------------------------------------------*/

/*--------------------------------------------------------------------------*/
/* 
 * creation of the menu
 */ 
U61_JoinMenu::U61_JoinMenu(U61_Menu *parent)
  : U61_Menu(parent,"Choose your server")
{
  add_item(new U61_Button("Join"));
  add_item(new U61_Edit("Server",U61_Global::config.server_id));
  select(0);
}

/*--------------------------------------------------------------------------*/
/*
 * performs an action, since a key press has been recorded
 */
U61_Menu *U61_JoinMenu::validate()
{
  U61_Menu *next_menu;

  next_menu=this;

  switch (selection)
    {
    case 0:
      next_menu=new U61_NonPausingMenu
	(new U61_NetworkMenu
	 (new U61_SaveScriptMenu
	  (new U61_ScoreMenu(this))));
      U61_Global::game.start_network_join();
      break;
    }

  return next_menu;
}

==> u61-1.0.0.tar.gz: u61-1.0.0/src/joinmenu.cpp <==
/****************************************************************************
 *                                                                          *
 * U U    6   1            U U   FFF  O   O  TTT                            *
 * U U   6   11   b        U U   F   O O O O  T                             *
 * U U - 66   1   bb  y y  U U - FF  O O O O  T                             *
 * U U   6 6  1   b b  y   U U   F   O O O O  T                             *
 *  U     6   1   bb   y    U    F    O   O   T                             *
 *                                                                          *
 * U61 is another block based game                                          *
 * Copyright (C) 2000 Christian Mauduit (ufoot@ufoot.org / www.ufoot.org)   *
 *                                                                          *
 * This program is free software; you can redistribute it and/or            *
 * modify it under the terms of the GNU General Public License              *
 * as published by the Free Software Foundation; either version 2           *
 * of the License, or (at your option) any later version.                   *
 *                                                                          *
 * This program is distributed in the hope that it will be useful,          *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of           *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
 * GNU General Public License for more details.                             *
 *                                                                          *
 * You should have received a copy of the GNU General Public License        *
 * along with this program; if not, write to the Free Software              *
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA*
 *                                                                          *
 * This project is also available on SourceForge  (http://sourceforge.net)  *
 ****************************************************************************/

/*
 * file name:   joinmenu.cpp
 * author:      U-Foot (ufoot@ufoot.org / www.ufoot.org)
 * description: allows the user to choose a remote machine and start
 *              a netwotk game being a client
 */

/*---------------------------------------------------------------------------
 includes
 ---------------------------------------------------------------------------*/

#include "joinmenu.h"
#include "networkmenu.h"
#include "nonpausingmenu.h"
#include "button.h"
#include "editaddress.h"
#include "global.h"
#include "savescriptmenu.h"
#include "scoremenu.h"
#include "debug.h"

/*---------------------------------------------------------------------------
 globals
 ---------------------------------------------------------------------------*/


/*---------------------------------------------------------------------------
 functions
 ---------------------------------------------------------------------------*/

/*--------------------------------------------------------------------------*/
/* 
 * creation of the menu
 */ 
U61_JoinMenu::U61_JoinMenu(U61_Menu *parent)
  : U61_Menu(parent,"Choose your server")
{
  //  add_item(new U61_Button("Join local server"));
  add_item(new U61_Button("Join server"));
  add_item(new U61_EditAddress("Server",U61_Global::config.server_id));
  select(0);
}

/*--------------------------------------------------------------------------*/
/*
 * performs an action, since a key press has been recorded
 */
U61_Menu *U61_JoinMenu::validate()
{
  U61_Menu *next_menu;

  next_menu=this;
  switch (selection)
    {
      /*
    case 0:
      next_menu=new U61_NonPausingMenu
      	(new U61_NetworkMenu
	 (new U61_SaveScriptMenu
	  (new U61_ScoreMenu(this))));
      U61_Global::game.start_network_broadcast();
      break;
      */
    case 0:
      next_menu=new U61_NonPausingMenu
	(new U61_NetworkMenu
	 (new U61_SaveScriptMenu
	  (new U61_ScoreMenu(this))));
      U61_Global::game.start_network_join();
      break;
    }
  return next_menu;
}
